# Changelog

## [0.4.0](https://www.github.com/bihealth/django-plugins/compare/v0.3.1...v0.4.0) (2023-07-18)


### Features

* cleanup setup, bump to 0.4.0 ([#8](https://www.github.com/bihealth/django-plugins/issues/8)) ([c9b0f6b](https://www.github.com/bihealth/django-plugins/commit/c9b0f6b44848f9c680ca2e57031a418c7d06ac73))

### 0.3.1 (2023-07-18)


### Features

* release for compatibility with Django >=3,<4 ([#2](https://www.github.com/bihealth/django-plugins/issues/2)) ([#3](https://www.github.com/bihealth/django-plugins/issues/3)) ([5d2e1d3](https://www.github.com/bihealth/django-plugins/commit/5d2e1d32c0af55f002130ba4c66e8785a75d7734))
